//
//  MMIUtils.h
//
//
//  Created by Martin Redington on 6/16/05.
//  Copyright 2005 __MyCompanyName__. All rights reserved.
//

//
// Copyright 2005-2007 MildMannered Industries. All right reserved.
// 
//


/*! @header MMIUtils.h
@discussion Provider of static utility methods.
*/


#import <Cocoa/Cocoa.h>
#import <sys/socket.h>
#import <netinet/in.h>
#import <arpa/inet.h>


@class MMIError;


/*!
@class MMIUtils
@abstract MMIUtils provides static utility methods for general usage.
@discussion Static utility methods only.
*/
@interface MMIUtils : NSObject {

}


@end

////////////////////////////////////////////////////////////////


@interface MMIUtils (INetAddressing)

/*!
@method getFamilyOfAddress:
	@abstract Returns the address family of the address encoded in the NSData object.
	@discussion This is the value of sockaddr->sa_family, where NSData is really a sockaddr
	@param address A pointer to the sockaddr structure.
	@result The sa_family value.
 */
+ (int) getFamilyOfAddress:(NSData *)address;

/*!
@method getHostFromAddress:
	@abstract Returns the ip address for the address encoded in the NSData object, as an NSString.
	@discussion This is the ip address from the sockaddr stucture where NSData is really a sockaddr
	@param address A pointer to the sockaddr structure.
	@result The IP address from the address, as an NSString.
 */
+ (NSString *) getHostFromAddress:(NSData *)address;

/*!
@method getPortFromAddress:
	@abstract Returns the port for the address encoded in the NSData object, as an int
	@discussion This is the port from the sockaddr stucture where NSData is really a sockaddr
	@param address A pointer to the sockaddr structure.
	@result The port number for the address, as an int
 */
+ (int) getPortFromAddress:(NSData *)address;

/*!
@method isPrivateAddress:
	@abstract Returns YES if the supplied address is a private internet address.
	@discussion The following addresses are private:
<ul>
<li> 10.0.0.0/8 (commonly used)
<li> 127.0.0.0/8 (loopback addresses)
<li> 169.254.0.0/16 (Micro$haft range) - We don't honour this one.
<li> 172.16.0.0/16 (least commonly used)
<li> 192.168.0.0/24 (most commonly used)
</ul> 
	@param address The address, in a.b.c.d notation as a string.
	@result YES if the address falls into one of the above ranges, NO otherwise.
 */
// + (BOOL) isPrivateAddress:(NSString *)address;


@end

////////////////////////////////////////////////////////////////

//@interface MMIUtils (Logging)
//
///*!
//@method log:format:
//	@abstract Logs the supplied message, formatting it as necessary.
//	@discussion This uses NSLog, but also logs the identity of the current thread.
//	@param format The format for the message.
// */
//+ (void) log:(NSString *) label format:(NSString *) format, ...;
//
//@end

////////////////////////////////////////////////////////////////


@interface MMIUtils (DictionarySupport)

/*!
@method readDictionary:
	@abstract Reads and returns the property list located at the supplied path.
	@discussion If the file cannot be read, or is not a valid property list. 
 If the file does not exist, a new empty dictionary will be returned.
	@param filePath The path to the property list file.
	@result A MutableDictionary with the contents of the file if any, 
 or nil if the file is not readable, or does not contain a property list.
 */
+ (NSMutableDictionary *) readDictionary:(NSString *) filePath;


/*!
@method writeDictionary:toPath:
	@abstract Writes the specified property list atomically to the supplied path.
	@discussion Returns YES if the file was written successfully, and NO otherwise.
 If the file does not exist, a new empty dictionary will be returned.
	@param dictionary The property list to save.
	@param filePath The path to save the property list to.
	@result YES if the file was written successfully, and NO otherwise.
 */
+ (BOOL) writeDictionary:(NSDictionary *) dictionary toPath:(NSString *) filePath;

@end

